# MH-django-config

This package is used to load configuration from different sources, and use it eventually to populate Django settings. It loads configuration (in json format) from local files, from AWS secret manager, and from GCP secret manager.

## Usage
